@@ -6,6 +6,10 @@
 #include "match.h"
 #include "options.h"
 
+#ifdef __cplusplus 
+extern "C" {
+#endif
+
 struct scored_result {
 	score_t score;
 	const char *str;
@@ -28,7 +32,7 @@ typedef struct {
 } choices_t;
 
 void choices_init(choices_t *c, options_t *options);
-void choices_fread(choices_t *c, FILE *file);
+void choices_fread(choices_t *c, FILE *file, char input_delimiter);
 void choices_destroy(choices_t *c);
 void choices_add(choices_t *c, const char *choice);
 size_t choices_available(choices_t *c);
@@ -38,4 +42,8 @@ score_t choices_getscore(choices_t *c, size_t n);
 void choices_prev(choices_t *c);
 void choices_next(choices_t *c);
 
+#ifdef __cplusplus 
+}
+#endif
+
 #endif
