@@ -1,3 +1,7 @@
+#ifdef __cplusplus 
+extern "C" {
+#endif
+
 #define TTY_COLOR_HIGHLIGHT TTY_COLOR_YELLOW
 
 #define SCORE_GAP_LEADING -0.005
@@ -11,3 +15,13 @@
 
 /* Time (in ms) to wait for additional bytes of an escape sequence */
 #define KEYTIMEOUT 25
+
+#define DEFAULT_TTY "/dev/tty"
+#define DEFAULT_PROMPT "> "
+#define DEFAULT_NUM_LINES 10
+#define DEFAULT_WORKERS 0
+#define DEFAULT_SHOW_INFO 0
+
+#ifdef __cplusplus 
+}
+#endif
