@@ -6,6 +6,8 @@
 
 #include "options.h"
 
+#include "../config.h"
+
 static const char *usage_str =
     ""
     "Usage: fzy [OPTION]...\n"
@@ -15,7 +17,9 @@ static const char *usage_str =
     " -e, --show-matches=QUERY Output the sorted matches of QUERY\n"
     " -t, --tty=TTY            Specify file to use as TTY device (default /dev/tty)\n"
     " -s, --show-scores        Show the scores of each match\n"
+    " -0, --read-null          Read input delimited by ASCII NUL characters\n"
     " -j, --workers NUM        Use NUM workers for searching. (default is # of CPUs)\n"
+    " -i, --show-info          Show selection info line\n"
     " -h, --help     Display this help and exit\n"
     " -v, --version  Output version information and exit\n";
 
@@ -29,37 +33,44 @@ static struct option longopts[] = {{"show-matches", required_argument, NULL, 'e'
 				   {"tty", required_argument, NULL, 't'},
 				   {"prompt", required_argument, NULL, 'p'},
 				   {"show-scores", no_argument, NULL, 's'},
+				   {"read-null", no_argument, NULL, '0'},
 				   {"version", no_argument, NULL, 'v'},
 				   {"benchmark", optional_argument, NULL, 'b'},
 				   {"workers", required_argument, NULL, 'j'},
+				   {"show-info", no_argument, NULL, 'i'},
 				   {"help", no_argument, NULL, 'h'},
 				   {NULL, 0, NULL, 0}};
 
 void options_init(options_t *options) {
 	/* set defaults */
-	options->benchmark = 0;
-	options->filter = NULL;
-	options->init_search = NULL;
-	options->tty_filename = "/dev/tty";
-	options->show_scores = 0;
-	options->num_lines = 10;
-	options->scrolloff = 1;
-	options->prompt = "> ";
-	options->workers = 0;
+	options->benchmark       = 0;
+	options->filter          = NULL;
+	options->init_search     = NULL;
+	options->show_scores     = 0;
+	options->scrolloff       = 1;
+	options->tty_filename    = DEFAULT_TTY;
+	options->num_lines       = DEFAULT_NUM_LINES;
+	options->prompt          = DEFAULT_PROMPT;
+	options->workers         = DEFAULT_WORKERS;
+	options->input_delimiter = '\n';
+	options->show_info       = DEFAULT_SHOW_INFO;
 }
 
 void options_parse(options_t *options, int argc, char *argv[]) {
 	options_init(options);
 
 	int c;
-	while ((c = getopt_long(argc, argv, "vhse:q:l:t:p:j:", longopts, NULL)) != -1) {
+	while ((c = getopt_long(argc, argv, "vhs0e:q:l:t:p:j:i", longopts, NULL)) != -1) {
 		switch (c) {
 			case 'v':
-				printf("%s " VERSION " © 2014-2018 John Hawthorn\n", argv[0]);
+				printf("%s " VERSION " © 2014-2025 John Hawthorn\n", argv[0]);
 				exit(EXIT_SUCCESS);
 			case 's':
 				options->show_scores = 1;
 				break;
+			case '0':
+				options->input_delimiter = '\0';
+				break;
 			case 'q':
 				options->init_search = optarg;
 				break;
@@ -100,6 +111,9 @@ void options_parse(options_t *options, int argc, char *argv[]) {
 				}
 				options->num_lines = l;
 			} break;
+			case 'i':
+				options->show_info = 1;
+				break;
 			case 'h':
 			default:
 				usage(argv[0]);
