@@ -1,6 +1,10 @@
 #ifndef OPTIONS_H
 #define OPTIONS_H OPTIONS_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct {
 	int benchmark;
 	const char *filter;
@@ -11,9 +15,15 @@ typedef struct {
 	unsigned int scrolloff;
 	const char *prompt;
 	unsigned int workers;
+	char input_delimiter;
+	int show_info;
 } options_t;
 
 void options_init(options_t *options);
 void options_parse(options_t *options, int argc, char *argv[]);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
