@@ -1,4 +1,3 @@
-#include <stdio.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <stdlib.h>
@@ -40,7 +39,7 @@ void tty_init(tty_t *tty, const char *tty_filename) {
 		exit(EXIT_FAILURE);
 	}
 
-	if (setvbuf(tty->fout, NULL, _IOFBF, 4096)) {
+	if (setvbuf(tty->fout, NULL, _IOFBF, 16384)) {
 		perror("setvbuf");
 		exit(EXIT_FAILURE);
 	}
@@ -184,6 +183,10 @@ void tty_printf(tty_t *tty, const char *fmt, ...) {
 	va_end(args);
 }
 
+void tty_putc(tty_t *tty, char c) {
+	fputc(c, tty->fout);
+}
+
 void tty_flush(tty_t *tty) {
 	fflush(tty->fout);
 }
