@@ -1,8 +1,14 @@
 #ifndef TTY_H
 #define TTY_H TTY_H
 
+#include <stddef.h>
+#include <stdio.h>
 #include <termios.h>
 
+#ifdef __cplusplus 
+extern "C" {
+#endif
+
 typedef struct {
 	int fdin;
 	FILE *fout;
@@ -51,9 +57,14 @@ void tty_moveup(tty_t *tty, int i);
 void tty_setcol(tty_t *tty, int col);
 
 void tty_printf(tty_t *tty, const char *fmt, ...);
+void tty_putc(tty_t *tty, char c);
 void tty_flush(tty_t *tty);
 
 size_t tty_getwidth(tty_t *tty);
 size_t tty_getheight(tty_t *tty);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
